SyncOutputSource<O> class
abstract
- Implemented types
-
- OutputSource<
O>
- OutputSource<
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
output
→ SyncOutput<
O> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listen(
void listener(SyncOutput< O> )) → Cancel -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited