Persistent<O> class
Constructors
-
Persistent({required String key, required PersistentStore store, required PersistentCodec<
O> codec}) -
const
Properties
-
codec
→ PersistentCodec<
O> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- store → PersistentStore
-
final
Methods
-
attach(
OutputSource< O> box) → void -
load(
) → O? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited